@@ -30,8 +30,8 @@ qx.Class.define("callbackery.ui.Popup", {
             centerOnContainerResize: true,
             centerOnAppear: true
         });
-        this.getApplicationRoot().addListener('resize',this.__setMaxWidth,this);
-        this.__setMaxWidth();
+        this.getApplicationRoot().addListener('resize',this.__autoMax,this);
+        this.__autoMax();
 
         if (cfg.set){
             this.set(cfg.set);
@@ -67,11 +67,12 @@ qx.Class.define("callbackery.ui.Popup", {
         },this);
     },
     members: {
-        __setMaxWidth: function() {
+        __autoMax: function() {
             let bounds = this.getApplicationRoot().getBounds();
             // make sure the window does not get larger than the screen by default ... 
             if (bounds) {
                 this.setMaxWidth(bounds.width-20);
+                this.setMaxHeight(bounds.height-20);
             }
         }
     },
